@@ -1,7 +1,8 @@
+from optparse import Option
 import os
 import logging
 from io import BytesIO
-from typing import Optional, Literal, Tuple, Union
+from typing import Optional, Literal, Tuple, Union, Dict, Any
 from datetime import datetime
 import base64
 
@@ -95,16 +96,17 @@ class DataAPIClient(BaseAPIClient):
     def get_data_manifest(
         self,
         dataset_id: str,
-        drop_date: Optional[Tuple[Literal["<", "<=", ">", "=>", "=="], Union[datetime, str]]] = None,
-        logical_date: Optional[Tuple[Literal["<", "<=", ">", "=>", "=="], Union[datetime, str]]] = None,
+        ontology_version: Optional[str] = None,
+        drop_date: Optional[Tuple[Literal["<", "<=", ">", ">=", "=="], Union[datetime, str]]] = None,
+        logical_date: Optional[Tuple[Literal["<", "<=", ">", ">=", "=="], Union[datetime, str]]] = None,
     ) -> dict:
         """
         Get the manifest for a specific data identifier from the Carbon Arc API.
         
         Args:
             dataset_id (str): The identifier of the data to retrieve manifest for.
-            drop_date (Optional[Tuple[Literal["<", "<=", ">", "=>", "=="], Union[datetime, str]]]): The filter for drop date.
-            logical_date (Optional[Tuple[Literal["<", "<=", ">", "=>", "=="], Union[datetime, str]]]): The filter for logical date.
+            drop_date (Optional[Tuple[Literal["<", "<=", ">", ">=", "=="], Union[datetime, str]]]): The filter for drop date.
+            logical_date (Optional[Tuple[Literal["<", "<=", ">", ">=", "=="], Union[datetime, str]]]): The filter for logical date.
             
         Returns:
             dict: A dictionary containing the manifest for the specified data identifier.
@@ -119,10 +121,19 @@ class DataAPIClient(BaseAPIClient):
         if logical_date:
             params["logical_date_operator"] = logical_date[0]
             params["logical_date"] = logical_date[1]
+            
+        if ontology_version:
+            params["ontology_version"] = ontology_version
         
         return self._get(url, params=params)
     
-    def buy_data(self, dataset_id: str, file_urls: list[str]) -> dict:
+    def buy_data(
+        self, 
+        dataset_id: str, 
+        ontology_version: Optional[str] = None,
+        drop_date: Optional[Tuple[Literal["<", "<=", ">", ">=", "=="], Union[datetime, str]]] = None,
+        logical_date: Optional[Tuple[Literal["<", "<=", ">", ">=", "=="], Union[datetime, str]]] = None,
+        file_urls: Optional[list[str]] = None) -> dict:
         """
         Buy data from the Carbon Arc API.
         
@@ -134,8 +145,11 @@ class DataAPIClient(BaseAPIClient):
         """
         endpoint = "data/buy"
         url = f"{self.base_data_url}/{endpoint}"
+        
+        if file_urls:                
+            log.warning("file_urls will be deprecated in carbonarc 1.2.0. Please use ontology_version, drop_date, and logical_date instead.")
 
-        return self._post(url, json={"order": {"dataset_id": dataset_id, "file_urls": file_urls}})
+        return self._post(url, json={"order": {"dataset_id": dataset_id, "ontology_version": ontology_version, "drop_date": drop_date, "logical_date": logical_date, "file_urls": file_urls}})
     
     def download_file(self, file_id: str, directory: str = "./", chunk_size: int = 5 * 1024 * 1024) -> str:
         """
@@ -541,4 +555,50 @@ class DataAPIClient(BaseAPIClient):
 
         except Exception as e:
             log.error(f"Google Cloud Storage upload failed due to: {str(e)}")
-            raise
\ No newline at end of file
+            raise
+
+    def get_library_version_changes(
+        self, 
+        version: str = "latest",
+        dataset_id: Optional[str] = None,
+        topic_id: Optional[int] = None,
+        entity_representation: Optional[str] = None,
+        page: Optional[int] = None,
+        size: Optional[int] = None,
+        order: Optional[str] = None
+    ) -> Dict[str, Any]:
+        """
+        Check if the data library version has changed for a specific dataset.
+
+        Args:
+            version: The version to check for changes against.
+            dataset_id: The dataset id to check for changes against.
+            topic_id: The topic id to check for changes against.
+            entity_representation: The entity representation to check for changes against.
+            page: The page number to check for changes against.
+            size: The size of the page to check for changes against.
+            order: The order of the query.
+
+        Returns:
+            A dictionary containing the changes in the data library version.
+        """
+        if page or size or order:
+            size = size or 100
+            page = page or 1
+            order = order or "asc"
+
+        params = {
+            "version": version.replace("v", ""),
+            "page": page,
+            "size": size,
+            "order": order
+        }
+        if dataset_id:
+            params["dataset_id"] = dataset_id
+        if topic_id:
+            params["topic_id"] = topic_id
+        if entity_representation:
+            params["entity_representation"] = entity_representation
+
+        url = f"{self.base_data_url}/data-library/version-changes"
+        return self._get(url, params=params)
\ No newline at end of file
